# Changelog
## 1.0.4 (2020-01-25)
### Misc
- Include LICENSE, CHANGES.md and README.md in the PyPi package.

## 1.0.3 (2020-01-25)
### Misc
- Extend supported version of `importlib-metadata` to the lowest.
